==> af-common-socket-1.1.14.58-sources.jar: com/af/v4/system/common/socket/core/client/ClientManager.java <==
package com.af.v4.system.common.socket.core.client;

import com.af.v4.system.common.plugins.core.ConvertTools;
import com.af.v4.system.common.socket.config.SocketConfigItem;
import com.af.v4.system.common.socket.core.channel.ChannelData;
import io.netty.channel.Channel;
import org.json.JSONObject;

/**
 * 客户端管理器
 */
public class ClientManager {
    private static final ThreadLocal<ChannelData> clientChannels = new ThreadLocal<>();

    public static void add(ChannelData channelData) {
        clientChannels.set(channelData);
    }

    public static void remove() {
        clientChannels.remove();
    }

    public static void send(String message) {
        ChannelData channelData = clientChannels.get();
        Channel channel = channelData.channel();
        byte[] sendMsgBytes;
        if (channel != null) {
            sendMsgBytes = switch (channelData.configItem().getEncodeType()) {
                default -> message.getBytes();
                case BASE64 -> ConvertTools.base64Decode(message.getBytes());
                case HEX -> ConvertTools.hexStrToByte(message);
                case HEX_BASE64 -> ConvertTools.base64Decode(ConvertTools.hexStrToByte(message));
            };
            channel.writeAndFlush(channel.alloc().buffer().writeBytes(sendMsgBytes));
        }
    }

    public static SocketConfigItem getConfig() {
        return clientChannels.get().configItem();
    }

    public static ChannelData getChannelData() {
        return clientChannels.get();
    }

    /**
     * 设置全局参数
     *
     * @param key   参数key
     * @param value 值
     */
    public static void setGlobalParams(String key, Object value) {
        ChannelData channelData = ClientManager.getChannelData();
        JSONObject globalParamsItem = channelData.globalParams();
        globalParamsItem.put(key, value);
    }

    /**
     * 获取全局参数
     *
     * @param key 参数key
     */
    public static Object getGlobalParams(String key) {
        ChannelData channelData = ClientManager.getChannelData();
        JSONObject globalParamsItem = channelData.globalParams();
        return globalParamsItem.opt(key);
    }
}

==> af-common-socket-1.1.16.54-sources.jar: com/af/v4/system/common/socket/core/client/ClientManager.java <==
package com.af.v4.system.common.socket.core.client;

import com.af.v4.system.common.plugins.core.ConvertTools;
import com.af.v4.system.common.socket.config.SocketConfigItem;
import com.af.v4.system.common.socket.core.channel.ChannelData;
import io.netty.channel.Channel;
import io.netty.util.HashedWheelTimer;
import org.json.JSONObject;

import java.util.concurrent.TimeUnit;

/**
 * 客户端管理器
 */
public class ClientManager {
    private static final ThreadLocal<ChannelData> clientChannels = new ThreadLocal<>();
    private static volatile HashedWheelTimer TIMER;

    private static HashedWheelTimer getTimer() {
        if (TIMER == null) {
            synchronized (ClientManager.class) {
                if (TIMER == null) {
                    TIMER = new HashedWheelTimer();
                }
            }
        }

        return TIMER;
    }

    public static void add(ChannelData channelData) {
        clientChannels.set(channelData);
    }

    public static void remove() {
        clientChannels.remove();
    }

    public static void delayedSend(String message, Integer sleepTime) {
        getTimer().newTimeout((timeout) -> send(message), Long.parseLong(sleepTime.toString()), TimeUnit.MILLISECONDS);
    }

    public static void send(String message) {
        ChannelData channelData = clientChannels.get();
        Channel channel = channelData.channel();
        byte[] sendMsgBytes;
        if (channel != null) {
            sendMsgBytes = switch (channelData.configItem().getEncodeType()) {
                default -> message.getBytes();
                case BASE64 -> ConvertTools.base64Decode(message.getBytes());
                case HEX -> ConvertTools.hexStrToByte(message);
                case HEX_BASE64 -> ConvertTools.base64Decode(ConvertTools.hexStrToByte(message));
            };
            channel.writeAndFlush(channel.alloc().buffer().writeBytes(sendMsgBytes));
        }
    }

    public static SocketConfigItem getConfig() {
        return clientChannels.get().configItem();
    }

    public static ChannelData getChannelData() {
        return clientChannels.get();
    }

    /**
     * 设置全局参数
     *
     * @param key   参数key
     * @param value 值
     */
    public static void setGlobalParams(String key, Object value) {
        ChannelData channelData = ClientManager.getChannelData();
        JSONObject globalParamsItem = channelData.globalParams();
        globalParamsItem.put(key, value);
    }

    /**
     * 获取全局参数
     *
     * @param key 参数key
     */
    public static Object getGlobalParams(String key) {
        ChannelData channelData = ClientManager.getChannelData();
        JSONObject globalParamsItem = channelData.globalParams();
        return globalParamsItem.opt(key);
    }
}
